#!/bin/bash
# this script convert constant fields to constant field with time axis
# sample, convert constant land/sea mask data to constant field in specified
#         time interval
# dependency: cdo (Climate Data Operator)
# Ufuk Utku Turuncoglu, 14 July 2006   

# define parameters
sc=$1 #"A2"
startdate=$2 #"2019-01-01"
starttime=$3 #"00:00"
timeint=$4 # "6hour"
year=$5 #2025
ind1=$6 #26297
ind2=$7 #27756
varname=$8 #"SLM"

# clean environment
rm -rf EH5_OM_${sc}_1_${varname}_*

# calculate constants
iend=$(($ind2-ind1+1))
echo "number of time step $iend"

# create multiple copies of the data
for i in `seq $ind1 $ind2` 
do
  echo ">>> EH5_OM_${sc}_1_${varname}_${i}-${i}.grb <<<"
  cp ${sc}_${year}/EH5_OM_CONST_${varname}_1-1.grb EH5_OM_${sc}_1_${varname}_${i}-${i}.grb 
done
sleep 2

# combine all dataset file into single one
# cdo has 1024 argument limitation
if [ $iend -gt 1024 ]; then
   echo "time step greater than 1024"
   diff=$(($iend - 1020))
   echo "diff  $diff" 
   cdo copy `ls -ltr EH5_OM_${sc}_1_${varname}_* | head -n 1020 | awk '{printf $9" "}'` EH5_OM_${sc}_1_${varname}_1-1020_cons.grb
   cdo copy `ls -ltr EH5_OM_${sc}_1_${varname}_* | tail -n $(($diff+1)) | head -n $diff | awk '{printf $9" "}'` EH5_OM_${sc}_1_${varname}_1021-${iend}_cons.grb
   cdo copy  EH5_OM_${sc}_1_${varname}_1-1020_cons.grb EH5_OM_${sc}_1_${varname}_1021-${iend}_cons.grb EH5_OM_${sc}_1_${varname}_1-${iend}_cons.grb 
fi

if [ $i -lt 1024 ]; then
   cdo copy `ls -ltr EH5_OM_${sc}_1_${varname}_* | awk '{printf $9" "}'` EH5_OM_${sc}_1_${varname}_1-${iend}_cons.grb
fi

rm -rf `ls -ltr EH5_OM_${sc}_1_${varname}_* | head -n $(($iend+2)) | awk '{printf $9" "}'`

# fix time axis data
cdo settaxis,$startdate,$starttime,$timeint EH5_OM_${sc}_1_${varname}_1-${iend}_cons.grb EH5_OM_${sc}_1_${varname}_${ind1}-${ind2}.grb
rm -rf EH5_OM_${sc}_1_${varname}_1-${iend}_cons.grb
mv EH5_OM_${sc}_1_${varname}_${ind1}-${ind2}.grb ${sc}_${year}/.
