#!/bin/bash
# arg 1 : scenario 20C | A2
# arg 2: year

function convert {
# arg 1: scenario 20C | A2
# arg 2: year
# arg 3: variable GPH | RELHUM | STP |   U   |   V
#        units     m  |   %    |  K  | m/sec | m/sec

# get list of files
lst=`ls -al ${1}_${2}/EH5_OM_${1}_1_${3}* | grep -v 10M | awk '{print $9}'`

# loop files
for i in $lst
do
  # create output variable name
  o=${i/.grb/.nc}
  o=`echo $o | awk -F/ '{print $2}'`
  o=`echo $o | awk -F_ '{print $5}'`
  o2=$o
  o=${o/$3/}

  if [ -n "$o" ]; then
    if [ $o -lt 100 ]; then
      o2="00$o-${3}.${2}.nc"
    elif [ $o -lt 1000 ]; then
      o2="0$o-${3}.${2}.nc"
    else
      o2="$o-${3}.${2}.nc"
    fi
  else 
    o2="$o2.${2}.nc"
  fi

  echo ">> cdo -r -f nc copy $i $o2 ..."
  # grb to nc
  cdo -r -f nc copy $i $o2

  # change lev dimension to record dimension
  if [ -n "$o" ]; then
    ncpdq -a lev,time $o2 $o2-lev 
    rm $o2
  fi
done

if [ -n "$o" ]; then
  # concentrate
  lst=`ls -al *${3}.${2}.nc-lev | awk '{printf $9" "}'`
  ncrcat $lst ${3}.${2}.nc-lev
  rm $lst

  # change time dimension to record dimension 
  ncpdq -a time,lev ${3}.${2}.nc-lev ${3}.${2}.nc
  rm ${3}.${2}.nc-lev
fi

# get variable name
vold=`ncks -m ${3}.${2}.nc | grep "ID = 4" | awk '{print $1}'`
if [ -z "$vold" ]; then
  vold=`ncks -m ${3}.${2}.nc | grep "ID = 3" | awk '{print $1}'`
fi
vold=${vold/:/}
vnew=`echo $3 | tr A-Z a-z`

# change variable name
if [ "$vold" != "$vnew" ]; then
  echo ">> rename from [$vold] to [$vnew]"
  ncrename -v $vold,$vnew ${3}.${2}.nc ${vnew}.${2}.nc
  rm ${3}.${2}.nc
else
  mv ${3}.${2}.nc ${vnew}.${2}.nc
fi
}

# main program
convert $1 $2 GPH
convert $1 $2 TSOIL
convert $1 $2 RELHUM
convert $1 $2 STP
convert $1 $2 U
convert $1 $2 V
convert $1 $2 TSW

#convert $1 $2 MSLP
#convert $1 $2 GPH500
#convert $1 $2 GPH850
#convert $1 $2 RELHUM1000
