#!/bin/bash
# This script split ECHAM5 grib data annually according
# to given date1 and date2. 
# dependency: cdo (Climate Data Operator)
# Ufuk Utku Turuncoglu, 14 July 2006  
#
# sample lsf command:
#	bsub -q trccsq -J 2031_ECHAM -o %J.out -e %J.err ./split.sh

# user defined parameters
ddir=$1   # "/SFS1/ufuk/A2" ... main data folder
sc=$2     # "A2" .............. scenario name, folder must be in /, such as /A2
year=$3   # 2025 .............. processed year 
istart=$4 # 35065 ............. start
iend=$5   # 36524 ............. end

dname=${sc}_${year} #${istart}-${iend}

# create output directory
mkdir $dname
cd $dname 
echo ">> Current Directory: `pwd`"
rm -rf *

# loop all files in input direcyory
for i in `ls -l $ddir | awk '{print $9}' | grep EH5_OM | grep -v _1-1.grb`
do
  k=`echo $i | awk -F_ '{print $7}'`

  echo "$i --> $k"
  if [$k -eq ""]; then
     out=`echo $i | awk -F_ '{print $1"_"$2"_"$3"_"$4"_"$5}'`
  else
     out=`echo $i | awk -F_ '{print $1"_"$2"_"$3"_"$4"_"$5"_"$6}'`
  fi 

  # get subset of the input dataset
  echo ">> Process File: $i [$out]"
  echo ">> Executed Command: grb selrec,$istart,$iend $ddir/$i ${out}_${istart}-${iend}.grb"
  grb selrec,$istart,$iend $ddir/$i ${out}_${istart}-${iend}.grb
  sleep 2 
done

# copy constant fields
cp $ddir/EH5_OM_CONST_SLM_1-1.grb .

# convert constant field to time dependent
cd -
echo ">> Current Directory: `pwd`"
echo ">> Executed Command: ./cons2t.sh "$sc" "$year-01-01" "00:00" "6hour" $year $istart $iend "SLM" " 
./cons2t.sh "$sc" "$year-01-01" "00:00" "6hour" $year $istart $iend "SLM" 
